@@ -1,12 +1,11 @@
 from __future__ import annotations
 
+import sys
 from io import BytesIO
 
 import pytest
 
-from PIL import Image
-
-from .helper import is_win32, skip_unless_feature
+from PIL import Image, features
 
 # Limits for testing the leak
 mem_limit = 1024 * 1048576
@@ -15,8 +14,10 @@ iterations = int((mem_limit / stack_size) * 2)
 test_file = "Tests/images/rgb_trns_ycbc.jp2"
 
 pytestmark = [
-    pytest.mark.skipif(is_win32(), reason="requires Unix or macOS"),
-    skip_unless_feature("jpg_2000"),
+    pytest.mark.skipif(
+        sys.platform.startswith("win32"), reason="requires Unix or macOS"
+    ),
+    pytest.mark.skipif(not features.check("jpg_2000"), reason="jpg_2000 not available"),
 ]
 
 
