@@ -59,7 +59,7 @@ irot_imir_to_exif_orientation(const avifImage *image) {
                 return axis ? 7   // 90 degrees anti-clockwise then swap left and right.
                             : 5;  // 90 degrees anti-clockwise then swap top and bottom.
             }
-            return 6;  // 90 degrees anti-clockwise.
+            return 8;  // 90 degrees anti-clockwise.
         }
         if (angle == 2) {
             if (imir) {
@@ -75,7 +75,7 @@ irot_imir_to_exif_orientation(const avifImage *image) {
                            ? 5   // 270 degrees anti-clockwise then swap left and right.
                            : 7;  // 270 degrees anti-clockwise then swap top and bottom.
             }
-            return 8;  // 270 degrees anti-clockwise.
+            return 6;  // 270 degrees anti-clockwise.
         }
     }
     if (imir) {
@@ -568,9 +568,7 @@ _encoder_add(AvifEncoderObject *self, PyObject *args) {
     }
 
 end:
-    if (&rgb) {
-        avifRGBImageFreePixels(&rgb);
-    }
+    avifRGBImageFreePixels(&rgb);
     if (!self->first_frame) {
         avifImageDestroy(frame);
     }
@@ -883,26 +881,22 @@ setup_module(PyObject *m) {
     return 0;
 }
 
+static PyModuleDef_Slot slots[] = {
+    {Py_mod_exec, setup_module},
+#ifdef Py_GIL_DISABLED
+    {Py_mod_gil, Py_MOD_GIL_NOT_USED},
+#endif
+    {0, NULL}
+};
+
 PyMODINIT_FUNC
 PyInit__avif(void) {
-    PyObject *m;
-
     static PyModuleDef module_def = {
         PyModuleDef_HEAD_INIT,
         .m_name = "_avif",
-        .m_size = -1,
         .m_methods = avifMethods,
+        .m_slots = slots
     };
 
-    m = PyModule_Create(&module_def);
-    if (setup_module(m) < 0) {
-        Py_DECREF(m);
-        return NULL;
-    }
-
-#ifdef Py_GIL_DISABLED
-    PyUnstable_Module_SetGIL(m, Py_MOD_GIL_NOT_USED);
-#endif
-
-    return m;
+    return PyModuleDef_Init(&module_def);
 }
