@@ -57,7 +57,10 @@ def cmd_nmake(
 
 
 def cmds_cmake(
-    target: str | tuple[str, ...] | list[str], *params: str, build_dir: str = "."
+    target: str | tuple[str, ...] | list[str],
+    *params: str,
+    build_dir: str = ".",
+    build_type: str = "Release",
 ) -> list[str]:
     if not isinstance(target, str):
         target = " ".join(target)
@@ -66,7 +69,7 @@ def cmds_cmake(
         " ".join(
             [
                 "{cmake}",
-                "-DCMAKE_BUILD_TYPE=Release",
+                f"-DCMAKE_BUILD_TYPE={build_type}",
                 "-DCMAKE_VERBOSE_MAKEFILE=ON",
                 "-DCMAKE_RULE_MESSAGES:BOOL=OFF",  # for NMake
                 "-DCMAKE_C_COMPILER=cl.exe",  # for Ninja
@@ -110,20 +113,20 @@ ARCHITECTURES = {
 }
 
 V = {
-    "BROTLI": "1.1.0",
-    "FREETYPE": "2.13.3",
+    "BROTLI": "1.2.0",
+    "FREETYPE": "2.14.1",
     "FRIBIDI": "1.0.16",
-    "HARFBUZZ": "11.0.1",
-    "JPEGTURBO": "3.1.0",
+    "HARFBUZZ": "12.3.0",
+    "JPEGTURBO": "3.1.3",
     "LCMS2": "2.17",
-    "LIBAVIF": "1.2.1",
-    "LIBIMAGEQUANT": "4.3.4",
-    "LIBPNG": "1.6.47",
-    "LIBWEBP": "1.5.0",
-    "OPENJPEG": "2.5.3",
-    "TIFF": "4.7.0",
-    "XZ": "5.8.1",
-    "ZLIBNG": "2.2.4",
+    "LIBAVIF": "1.3.0",
+    "LIBIMAGEQUANT": "4.4.1",
+    "LIBPNG": "1.6.53",
+    "LIBWEBP": "1.6.0",
+    "OPENJPEG": "2.5.4",
+    "TIFF": "4.7.1",
+    "XZ": "5.8.2",
+    "ZLIBNG": "2.3.2",
 }
 V["LIBPNG_XY"] = "".join(V["LIBPNG"].split(".")[:2])
 
@@ -146,18 +149,17 @@ DEPS: dict[str, dict[str, Any]] = {
         },
         "build": [
             *cmds_cmake(
-                ("jpeg-static", "cjpeg-static", "djpeg-static"),
+                ("jpeg-static", "djpeg-static"),
                 "-DENABLE_SHARED:BOOL=FALSE",
                 "-DWITH_JPEG8:BOOL=TRUE",
                 "-DWITH_CRT_DLL:BOOL=TRUE",
             ),
             cmd_copy("jpeg-static.lib", "libjpeg.lib"),
-            cmd_copy("cjpeg-static.exe", "cjpeg.exe"),
             cmd_copy("djpeg-static.exe", "djpeg.exe"),
         ],
         "headers": ["jconfig.h", r"src\j*.h"],
         "libs": ["libjpeg.lib"],
-        "bins": ["cjpeg.exe", "djpeg.exe"],
+        "bins": ["djpeg.exe"],
     },
     "zlib": {
         "url": f"https://github.com/zlib-ng/zlib-ng/archive/refs/tags/{V['ZLIBNG']}.tar.gz",
@@ -165,12 +167,12 @@ DEPS: dict[str, dict[str, Any]] = {
         "license": "LICENSE.md",
         "patch": {
             r"CMakeLists.txt": {
-                "set_target_properties(zlib PROPERTIES OUTPUT_NAME zlibstatic${{SUFFIX}})": "set_target_properties(zlib PROPERTIES OUTPUT_NAME zlib)",  # noqa: E501
+                "set_target_properties(zlib-ng PROPERTIES OUTPUT_NAME zlibstatic${{SUFFIX}})": "set_target_properties(zlib-ng PROPERTIES OUTPUT_NAME zlib)",  # noqa: E501
             },
         },
         "build": [
             *cmds_cmake(
-                "zlib", "-DBUILD_SHARED_LIBS:BOOL=OFF", "-DZLIB_COMPAT:BOOL=ON"
+                "zlib-ng", "-DBUILD_SHARED_LIBS:BOOL=OFF", "-DZLIB_COMPAT:BOOL=ON"
             ),
         ],
         "headers": [r"z*.h"],
@@ -181,11 +183,7 @@ DEPS: dict[str, dict[str, Any]] = {
         "filename": f"xz-{V['XZ']}.tar.gz",
         "license": "COPYING",
         "build": [
-            *cmds_cmake(
-                "liblzma",
-                "-DBUILD_SHARED_LIBS:BOOL=OFF"
-                + (" -DXZ_CLMUL_CRC:BOOL=OFF" if struct.calcsize("P") == 4 else ""),
-            ),
+            *cmds_cmake("liblzma", "-DBUILD_SHARED_LIBS:BOOL=OFF"),
             cmd_mkdir(r"{inc_dir}\lzma"),
             cmd_copy(r"src\liblzma\api\lzma\*.h", r"{inc_dir}\lzma"),
         ],
@@ -226,12 +224,6 @@ DEPS: dict[str, dict[str, Any]] = {
                 # link against libwebp.lib
                 "#ifdef WEBP_SUPPORT": '#ifdef WEBP_SUPPORT\n#pragma comment(lib, "libwebp.lib")',  # noqa: E501
             },
-            r"test\CMakeLists.txt": {
-                "add_executable(test_write_read_tags ../placeholder.h)": "",
-                "target_sources(test_write_read_tags PRIVATE test_write_read_tags.c)": "",  # noqa: E501
-                "target_link_libraries(test_write_read_tags PRIVATE tiff)": "",
-                "list(APPEND simple_tests test_write_read_tags)": "",
-            },
         },
         "build": [
             *cmds_cmake(
@@ -239,7 +231,6 @@ DEPS: dict[str, dict[str, Any]] = {
                 "-DBUILD_SHARED_LIBS:BOOL=OFF",
                 "-DWebP_LIBRARY=libwebp",
                 '-DCMAKE_C_FLAGS="-nologo -DLZMA_API_STATIC"',
-                "-DCMAKE_POLICY_VERSION_MINIMUM=3.5",
             )
         ],
         "headers": [r"libtiff\tiff*.h"],
@@ -385,10 +376,11 @@ DEPS: dict[str, dict[str, Any]] = {
         "bins": [r"*.dll"],
     },
     "libavif": {
-        "url": f"https://github.com/AOMediaCodec/libavif/archive/v{V['LIBAVIF']}.zip",
-        "filename": f"libavif-{V['LIBAVIF']}.zip",
+        "url": f"https://github.com/AOMediaCodec/libavif/archive/v{V['LIBAVIF']}.tar.gz",
+        "filename": f"libavif-{V['LIBAVIF']}.tar.gz",
         "license": "LICENSE",
         "build": [
+            "rustup update",
             f"{sys.executable} -m pip install meson",
             *cmds_cmake(
                 "avif_static",
@@ -396,10 +388,11 @@ DEPS: dict[str, dict[str, Any]] = {
                 "-DAVIF_LIBSHARPYUV=LOCAL",
                 "-DAVIF_LIBYUV=LOCAL",
                 "-DAVIF_CODEC_AOM=LOCAL",
+                "-DCONFIG_AV1_HIGHBITDEPTH=0",
+                "-DAVIF_CODEC_AOM_DECODE=OFF",
                 "-DAVIF_CODEC_DAV1D=LOCAL",
-                "-DAVIF_CODEC_RAV1E=LOCAL",
-                "-DAVIF_CODEC_SVT=LOCAL",
-                "-DCMAKE_POLICY_VERSION_MINIMUM=3.5",
+                "-DCMAKE_INTERPROCEDURAL_OPTIMIZATION=ON",
+                build_type="MinSizeRel",
             ),
             cmd_xcopy("include", "{inc_dir}"),
         ],
@@ -755,7 +748,7 @@ def main() -> None:
         disabled += ["libimagequant"]
     if args.no_fribidi:
         disabled += ["fribidi"]
-    if args.no_avif or args.architecture != "AMD64":
+    if args.no_avif or args.architecture == "ARM64":
         disabled += ["libavif"]
 
     prefs = {
